@@ -12,7 +12,6 @@ from gaea.models import (
     Apiaries,
     HoneyTypes,
     Comments,
-    CommentTypes,
     Events,
     EventStatuses,
     EventTypes,
@@ -92,19 +91,23 @@ DATASETS = (
             user_id=IDS["Users"][-1],
         ),
         HoneyTypes(
-            id=IDS["Honey_types"][0], name=HONEY_TYPE_ALL_FLOWERS, user_id=IDS["Users"][0]
+            id=IDS["Honey_types"][0],
+            name=HONEY_TYPE_ALL_FLOWERS,
+            user_id=IDS["Users"][0],
         ),
         HoneyTypes(
             id=IDS["Honey_types"][1], name=HONEY_TYPE_CHESTNUT, user_id=IDS["Users"][0]
         ),
-        HoneyTypes(
-            id=IDS["Honey_types"][-1], name="unknown", user_id=IDS["Users"][-1]
+        HoneyTypes(id=IDS["Honey_types"][-1], name="unknown", user_id=IDS["Users"][-1]),
+        HiveConditions(
+            id=IDS["Hive_conditions"][0],
+            name=HIVES_CONDITION_NEW,
+            user_id=IDS["Users"][0],
         ),
         HiveConditions(
-            id=IDS["Hive_conditions"][0], name=HIVES_CONDITION_NEW, user_id=IDS["Users"][0]
-        ),
-        HiveConditions(
-            id=IDS["Hive_conditions"][1], name=HIVES_CONDITION_OLD, user_id=IDS["Users"][0]
+            id=IDS["Hive_conditions"][1],
+            name=HIVES_CONDITION_OLD,
+            user_id=IDS["Users"][0],
         ),
         HiveConditions(
             id=IDS["Hive_conditions"][-1], name="unknown", user_id=IDS["Users"][-1]
@@ -133,9 +136,6 @@ DATASETS = (
         EventStatuses(
             id=IDS["Event_statuses"][-1], name="unknown", user_id=IDS["Users"][-1]
         ),
-        CommentTypes(id=IDS["Comment_types"][0], name=COMMENT_TYPE_USER),
-        CommentTypes(id=IDS["Comment_types"][1], name=COMMENT_TYPE_SYSTEM),
-        CommentTypes(id=IDS["Comment_types"][-1], name="unknown"),
     ),
     (
         Swarms(
@@ -255,46 +255,46 @@ DATASETS = (
         Comments(
             id=uuid.uuid4(),
             comment="comment1",
+            type="user",
             date=datetime.datetime.utcnow(),
             user_id=IDS["Users"][0],
-            type_id=IDS["Comment_types"][0],
             swarm_id=IDS["Swarms"][0],
             hive_id=IDS["Hives"][0],
         ),
         Comments(
             id=uuid.uuid4(),
             comment="comment2",
+            type="user",
             date=datetime.datetime.utcnow(),
             user_id=IDS["Users"][0],
-            type_id=IDS["Comment_types"][1],
             event_id=IDS["Events"][0],
         ),
         Comments(
             id=uuid.uuid4(),
             comment="comment3",
+            type="user",
             date=datetime.datetime.utcnow(),
             user_id=IDS["Users"][0],
-            type_id=IDS["Comment_types"][0],
             swarm_id=IDS["Swarms"][1],
             hive_id=IDS["Hives"][1],
         ),
         Comments(
             id=uuid.uuid4(),
             comment="comment4",
+            type="user",
             date=datetime.datetime.utcnow(),
             user_id=IDS["Users"][0],
-            type_id=IDS["Comment_types"][0],
             swarm_id=IDS["Swarms"][0],
             hive_id=IDS["Hives"][0],
         ),
         Comments(
             id=uuid.uuid4(),
             comment="unknown",
+            type="user",
             date=datetime.datetime.utcnow(),
             user_id=IDS["Users"][-1],
-            type_id=IDS["Comment_types"][-1],
             swarm_id=IDS["Swarms"][-1],
             hive_id=IDS["Hives"][-1],
         ),
-    )
-)
\ No newline at end of file
+    ),
+)
